#
# spec file for package fakechroot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fakechroot
Version:        2.20.1
Release:        3.2
Summary:        Preloadable library for a fake chroot environment
License:        GPL-2.0-or-later AND LGPL-2.1-only AND LGPL-2.1-or-later AND GPL-3.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/dex4er/fakechroot/wiki
Source0:        https://github.com/dex4er/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
# Patch from:   https://github.com/dex4er/fakechroot/pull/85
Patch0:         %{name}-glibc-233.patch

%description
fakechroot runs a command in an environment where it is possible to use the
chroot(8) command without root privileges. This is useful for allowing users to
create own chrooted environments with the possibility to install other packages
without the need for root privileges.

fakechroot does this by replacing some libc library functions (chroot(2),
open(2), etc.) by ones that simulate the effect of being called with root
privileges.

These wrapper functions are in a shared library called libfakechroot.so, which
can be loaded through the LD_PRELOAD mechanism of the dynamic loader.

%prep
%autosetup -p1

%build
%define _lto_cflags %{nil}
# Workaround for boo#1229277:
%global optflags %{optflags} -Wno-error=implicit-function-declaration
%configure \
  --disable-static
%make_build

%check
# Allways fail in our build environment:
# FAIL t/escape-nested-chroot.t (exit status: 1)
%make_build check || true

%install
%make_install

%files
%license COPYING LICENSE
%doc NEWS.md README.md THANKS.md
%doc scripts/restoremode.sh scripts/savemode.sh
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*
%{_bindir}/env.%{name}
%{_bindir}/%{name}
%{_bindir}/ldd.%{name}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib%{name}.la
%{_libdir}/%{name}/lib%{name}.so
%{_sbindir}/chroot.%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Mon Aug 19 2024 Martin Jambor <mjambor@suse.com>
- Add -Wno-error=implicit-function-declaration to optflags to work
  around a bothched configure result and allow buiding the package
  with GCC 14. [boo#1229277]
* Tue Mar  2 2021 Avindra Goolcharan <avindra@opensuse.org>
- add fakechroot-glibc-233.patch to fix glibc 2.33 compatibility
* Wed May  6 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.20.1
  * Fixed problem when tests couldn't be started with root user and
    glibc 2.28.
  * Fixed problem with too verbose test for debootstrap(8) command.
  * Fixed problem with tests for fts_* functions when started on
    btrfs filesystem.
  - The debootstrap(8) command honors FAKECHROOT_EXTRA_LIBRARY_PATH
    environment variable too.
  * Workaround has been added for systemd package installed by
    debootstrap(8) command.
  * Better support for link-time optimizer.
- Changes for version 2.20:
  * The fts64_* functions were added: glibc supports them since
    2.23.
  * The renameat2(2) function were added: glibc supports it since
    2.28 and mv command from coreutils 8.30 uses it.
  * The chroot(8) wrapper and fakechroot(1) command can work with
    POSIX shell.
  * The chroot(8) wrapper allows to chroot into root directory.
  * The chroot(8) wrapper appends directories from
  * FAKECHROOT_EXTRA_LIBRARY_PATH environment variable because some
    commands use runpath. The default value is
    /lib/systemd:/usr/lib/man-db forsystemctl(1) and man(1)
    commands.
  * The ldd(1) wrapper doesn't lose a leading slash in absolute
    paths.
  * The fakechroot(1) command unsets CDPATH environment variable
    and swaps libfakeroot and libfakechroot in LD_PRELOAD
    environment variable if needed.
  * Can be compiled with gcc 7.1 -Wformat-truncation.
  * Can be compiled with clang 5.0 -O2 and -std=c11.
* Wed Sep 11 2019 Martin Pluskal <mpluskal@suse.com>
- Use modern macros
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tag.
- Disable lto before building fakechroot.
* Thu Nov 29 2018 Jan Engelhardt <jengelh@inai.de>
- Update description. Use noun phrase in summary.
* Tue Nov 27 2018 Martin Liška <mliska@suse.cz>
- Make build and tests run in verbose mode.
* Thu Dec 28 2017 jengelh@inai.de
- Fix language errors in description.
* Sat Jan 14 2017 munix9@googlemail.com
- update to version 2.19
  * The FAKECHROOT_EXCLUDE_PATH list has to contain at most 100
    elements.
  * The env(1) wrapper works with dash.
  * The fakeroot(1) works if chroot(8) is invoked twice.
  * Fixes were made for chdir(2). It was possible to change to a
    directory outside of fakechroot.
  * The fakechroot(1) command sets FAKECHROOT_CMD_ORIG environment
    variable for wrapped command.
  * The ldd(1) wrapper distinguishes different paths with the same
    beginning.
  * The ldd(1) wrapper does not fail if the path is not existing
    outside fakechroot.
  * Can be compiled with clang 4.0.
* Sun Feb  7 2016 munix9@googlemail.com
- update to version 2.18
  * The fakechroot(1) command accepts new option --bindir.
  * The chfn(1) command runs correctly on Ubuntu vidid and Debian stretch.
  * The env(1) wrapper works correctly if there is variable with multilined content.
  * New functions ldaddr(3) and dl_iterate_phdr(3) were added.
    The dlopen(3) function was fixed.
    The java(1) command should work correctly.
  * New functions posix_spawn(3) and posix_spawnp(3) were added.
    Some new applications like clang(1) should run properly.
  * Fixes were made for lstat(2) and lstat64(2) functions.
    The ending slash is not removed by normalization of a path name.
  * Fixes were made for readlink(2) function.
    The fakechroot(1) command runs properly with libjemalloc library.
  * The tilde ~ character in FAKECHROOT_* variables is not expanded anymore.
  * Fixes were made for getpeeraddr(3) and getsockaddr(3) functions.
* Fri Dec  5 2014 munix9@googlemail.com
- initial package for version 2.17.2
